<?php
	class cmsWysiwygTrumbowyg {
		
		private static $redactor_loaded = false;
		
		public function displayEditor($field_id, $content=''){
			
			$this->loadRedactor();
			
			$dom_id = str_replace(array('[',']'), array('_', ''), $field_id);
			
			echo html_textarea($field_id, $content, array('id' => $dom_id, 'class' => 'imperavi_redactor'));
			
		}
		
		private function loadRedactor() {
			
			if(self::$redactor_loaded){ return false; }
			
			$lang = cmsCore::getLanguageName();
			
			$template = cmsTemplate::getInstance();
			$user = cmsUser::getInstance();
			$core = cmsCore::getInstance();
			
			$template->addJSFromContext('wysiwyg/trumbowyg/trumbowyg.js');
			$template->addCSSFromContext('wysiwyg/trumbowyg/ui/trumbowyg.css');
			$template->addCSSFromContext('wysiwyg/trumbowyg/plugins/emoji/ui/trumbowyg.emoji.css');
			$template->addJSFromContext('templates/default/js/files.js');
			$template->addJSFromContext('wysiwyg/trumbowyg/plugins/emoji/trumbowyg.emojify.js');
			
			$options = array();
			
			$plugins = array(
            'upload',
            'noembed',
            'emoji',
            'pasteembed'
			);
			
			foreach($plugins as $plugin){
				
				$options['plugins'][] = $plugin;
				
				$template->addJSFromContext('wysiwyg/trumbowyg/plugins/'.$plugin.'/trumbowyg.'.$plugin.'.js');
				
			}
			
			if($lang !== 'en'){
				
				$template->addJSFromContext('wysiwyg/trumbowyg/langs/'.$lang.'.min.js');
				
				$options['lang'] = $lang;
				
			}
			
			//конвертирование ссылок vimeo и youtube
			$options['convertVideoLinks'] = true;
			
			//авторесайз поля ввода
			$options['autoresize'] = true;
			
			//отмена конвертирования дивов в параграфы
			$options['convertDivs'] = false;
			
			// прилипание тулбара
			$options['toolbarFixed'] = true;
			
			if (!$user->is_admin) {
				$options['buttonSource'] = false;
			}
			
			if ($user->is_logged) {
				
				$context = $core->getUriData();
				$upload_params = array();
				
				if($context['controller']){
					$upload_params['target_controller'] = $context['controller'];
				}
				
				if($context['action']){
					$upload_params['target_subject'] = $context['action'];
				}
				
				if(strpos($core->uri, '/add/') === false && !empty($context['params'][0]) && is_numeric($context['params'][0])){
					$upload_params['target_id'] = $context['params'][0];
				}
				
				$options['imageUpload'] = href_to('trumbowyg/upload').($upload_params ? '?'.http_build_query($upload_params) : '');
				
				$options['imageGetJson'] = href_to('redactor/images_list').($upload_params ? '?'.http_build_query($upload_params) : '');
				
				if($context['controller'] && $context['action']){
					$options['predefinedLinks'] = href_to('redactor/links_list').($upload_params ? '?'.http_build_query($upload_params) : '');
				}
				
			}
			
			$options['minHeight'] = 200;
			
		?>
        <script type="text/javascript">
            $(function(){
                $('.imperavi_redactor').trumbowyg({
					lang: 'ru',
					btnsDef: {
						text: {
							dropdown: ['strong', 'em', 'del', 'underline'],
							title: 'Оформление',
							text: 'Оформление',
							ico: 'strong'
						},
						image: {
							dropdown: ['insertImage', 'upload'],
							title: 'Изображение',
							text: 'Изображение',
							ico: 'insertImage'
						},
						align: {
							dropdown: ['justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull'],
							title: 'Выровнять',
							text: 'Выровнять',
							ico: 'justifyCenter'
						},
						noembed: {
							title: 'Видео'
						},
						insertImage: {
							title: 'Вставить'
						}
					},
					plugins: {
						upload: {
							serverPath: '<?php echo $options['imageUpload'];?>',
							fileFieldName: 'file',
							urlPropertyName: 'filelink',
							imageWidthModalEdit: true	
						}
					},
					btns: [
					['viewHTML'],
					['undo', 'redo'], // Only supported in Blink browsers
					['formatting'],
					['text'],
					['link'],
					['image'],
					['noembed'],
					['align'],
					['emoji'],
					['horizontalRule'],
					['removeformat'],
					['fullscreen']
					],
					autogrow: true
				});
				$('.trumbowyg-dropdown-emoji').on('input propertychange', function() {
					emojify.setConfig({
						img_dir : '//cdnjs.cloudflare.com/ajax/libs/emojify.js/1.1.0/images/basic/',
					});
					console.log(emojify);
					emojify.run();
				});
			});
		</script>
		
		
		<?php
			
			self::$redactor_loaded = true;
			
		}
		
	}
